@@ -1,10 +1,12 @@
 from captcha.conf import settings as captcha_settings
 from django.db import models
 from django.conf import settings
+from django.utils.encoding import smart_text
 import datetime
 import random
 import time
-import unicodedata
+import hashlib
+
 
 # Heavily based on session key generation in Django
 # Use the system (hardware-based) random number generator if it exists.
@@ -12,14 +14,7 @@ if hasattr(random, 'SystemRandom'):
     randrange = random.SystemRandom().randrange
 else:
     randrange = random.randrange
-MAX_RANDOM_KEY = 18446744073709551616L     # 2 << 63
-
-
-try:
-    import hashlib  # sha for Python 2.5+
-except ImportError:
-    import sha  # sha for Python 2.4 (deprecated in Python 2.6)
-    hashlib = False
+MAX_RANDOM_KEY = 18446744073709551616     # 2 << 63
 
 
 def get_safe_now():
@@ -41,14 +36,15 @@ class CaptchaStore(models.Model):
     def save(self, *args, **kwargs):
         self.response = self.response.lower()
         if not self.expiration:
-            #self.expiration = datetime.datetime.now() + datetime.timedelta(minutes=int(captcha_settings.CAPTCHA_TIMEOUT))
             self.expiration = get_safe_now() + datetime.timedelta(minutes=int(captcha_settings.CAPTCHA_TIMEOUT))
         if not self.hashkey:
-            key_ = unicodedata.normalize('NFKD', str(randrange(0, MAX_RANDOM_KEY)) + str(time.time()) + unicode(self.challenge)).encode('ascii', 'ignore') + unicodedata.normalize('NFKD', unicode(self.response)).encode('ascii', 'ignore')
-            if hashlib:
-                self.hashkey = hashlib.sha1(key_).hexdigest()
-            else:
-                self.hashkey = sha.new(key_).hexdigest()
+            key_ = (
+                smart_text(randrange(0, MAX_RANDOM_KEY)) +
+                smart_text(time.time()) +
+                smart_text(self.challenge, errors='ignore') +
+                smart_text(self.response, errors='ignore')
+            ).encode('utf8')
+            self.hashkey = hashlib.sha1(key_).hexdigest()
             del(key_)
         super(CaptchaStore, self).save(*args, **kwargs)
 
@@ -58,3 +54,10 @@ class CaptchaStore(models.Model):
     def remove_expired(cls):
         cls.objects.filter(expiration__lte=get_safe_now()).delete()
     remove_expired = classmethod(remove_expired)
+
+    @classmethod
+    def generate_key(cls):
+        challenge, response = captcha_settings.get_challenge()()
+        store = cls.objects.create(challenge=challenge, response=response)
+
+        return store.hashkey
